# ApiCore package

A library to construct API's using Transactor and abstact context- and database-independent Data Transfer Objects 

#### Requirements:
- Apache
- PHP >= 7.0
- MariaDB server
- Laravel 5.4 or 5.5, or Lumen installation
- Composer

### Installation
1. Request access to repository https://github.com/insegment/api-infusemedia
2. Add repository to your project's composer.json:

```
"repositories": [ { "type": "vcs", "url": "git@github.com:insegment/api-infusemedia.git" } ],
```

3. Add into require section:

```
"insegment/api-core": "dev-master"
```

4. Edit .env:

```
API_DEBUG_NO_REAL_ENCRYPTION=true
API_TRANSACTION_DEBUG=false
API_CURRENT_VERSION=1.0
```

5. (skip if already done) You may need to php artisan key:generate and update .env:

```
APP_KEY=base64:INSERT_KEY_THERE
```

6. If you haven't already enabled session support, enable it. In Lumen add the config and use the following code in bootstrap:

```
$app->middleware([
    \Illuminate\Cookie\Middleware\EncryptCookies::class,
    \Illuminate\Cookie\Middleware\AddQueuedCookiesToResponse::class,
    \Illuminate\Session\Middleware\StartSession::class
]);

$app->configure('session');
$app->singleton('session', function () use ($app) {
    return new \Illuminate\Session\SessionManager($app);
});

$app->singleton('session.store', function () use ($app) {
    return $app->make('session')->driver();
});

$app->singleton(\Illuminate\Session\Middleware\StartSession::class, function () use ($app) {
    return new \Illuminate\Session\Middleware\StartSession($app->make('session'));
});

$app->register(\Illuminate\Cookie\CookieServiceProvider::class);
$app->bind('Illuminate\Contracts\Cookie\QueueingFactory', 'cookie');
```

7. Register ApiCore service providers:

```
InSegment\ApiCore\Providers\EloquentSerivceProvider::class,
InSegment\ApiCore\Providers\ApiCoreServiceProvider::class,
```

8. Register routes from vendor/insegment/api-core/routes/lumen/transfer_api.php with namespace InSegment\ApiCore\Controllers
9. Create folder App\Api with the following structure:
```
App\Api
App\Api\V_1_0\DTODefs.php
App\Api\V_1_0\rules.json
```

10. In DTODefs extend DTOUtil and implement all abstract methods
11. Write rules in rules.json for all classes you want to use; [How to Write Rules](src/Api/V_1_0/rules.md)
12. Add Transactible trait and TransactibleModel interface to all Eloquent Models used in transactions